@@ -2,6 +2,12 @@
 
 #define QT_FEATURE_gc_binaries -1
 
+#define QT_FEATURE_use_bfd_linker -1
+
+#define QT_FEATURE_use_gold_linker -1
+
+#define QT_FEATURE_use_lld_linker -1
+
 #define QT_FEATURE_private_tests -1
 
 #define QT_FEATURE_debug -1
@@ -58,6 +64,10 @@
 
 #define QT_FEATURE_neon 1
 
+#define QT_FEATURE_arm_crc32 -1
+
+#define QT_FEATURE_arm_crypto -1
+
 #define QT_FEATURE_posix_fallocate 1
 
 #define QT_FEATURE_alloca_h 1
@@ -80,6 +90,8 @@
 
 #define QT_FEATURE_network 1
 
+#define QT_FEATURE_printsupport 1
+
 #define QT_FEATURE_sql 1
 
 #define QT_FEATURE_testlib 1
